@@ -29,6 +29,7 @@ const Gtk = imports.gi.Gtk;
 const Lang = imports.lang;
 
 const Application = imports.application;
+const Place = imports.place;
 const PlaceStore = imports.placeStore;
 const SearchPopup = imports.searchPopup;
 const Utils = imports.utils;
@@ -160,24 +161,12 @@ const PlaceEntry = new Lang.Class({
     },
 
     _completionVisibleFunc: function(model, iter) {
-        let name = model.get_value(iter, PlaceStore.Columns.NAME);
-        let key = this.text;
+        let place = model.get_value(iter, PlaceStore.Columns.PLACE);
 
-        if (key.length === 0)
-            return true;
-
-        if (name === null)
+        if (place !== null)
+            return place.match(this.text);
+        else
             return false;
-
-        key = GLib.utf8_normalize(key, -1, GLib.NormalizeMode.ALL);
-        if (key === null)
-            return false;
-
-        name = GLib.utf8_normalize(name, -1, GLib.NormalizeMode.ALL);
-        if (name === null)
-            return false;
-
-        return name.toLowerCase().search(key.toLowerCase()) !== -1;
     },
 
     _validateCoordinates: function(lat, lon) {
@@ -208,7 +197,7 @@ const PlaceEntry = new Lang.Class({
 
         let parsedLocation = this._parseCoordinates(this.text);
         if (parsedLocation) {
-            this.place = new Geocode.Place({ location: parsedLocation });
+            this.place = new Place.Place({ location: parsedLocation });
             return true;
         }
 
